==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/FilterDialogRenderCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterDialogRenderCompletedEventArgsDescription } from "./FilterDialogRenderCompletedEventArgsDescription";
/**
 * @hidden
 */
var FilterDialogRenderCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FilterDialogRenderCompletedEventArgsDescriptionMetadata, _super);
    function FilterDialogRenderCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (FilterDialogRenderCompletedEventArgsDescriptionMetadata.a == null) {
            FilterDialogRenderCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FilterDialogRenderCompletedEventArgsDescriptionMetadata.c(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.k(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
    };
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.c = function (a) {
    };
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.d = function (a) {
        FilterDialogRenderCompletedEventArgsDescriptionMetadata.b(a);
        a.ad("FilterDialogRenderCompletedEventArgs", function () { return new FilterDialogRenderCompletedEventArgsDescription(); });
        a.ac("FilterDialogRenderCompletedEventArgs", FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
    };
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.$t = markType(FilterDialogRenderCompletedEventArgsDescriptionMetadata, 'FilterDialogRenderCompletedEventArgsDescriptionMetadata');
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.a = null;
    return FilterDialogRenderCompletedEventArgsDescriptionMetadata;
}(Base));
export { FilterDialogRenderCompletedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/FilterDialogRenderCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterDialogRenderCompletedEventArgsDescription } from "./FilterDialogRenderCompletedEventArgsDescription";
/**
 * @hidden
 */
var FilterDialogRenderCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FilterDialogRenderCompletedEventArgsDescriptionMetadata, _super);
    function FilterDialogRenderCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (FilterDialogRenderCompletedEventArgsDescriptionMetadata.a == null) {
            FilterDialogRenderCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FilterDialogRenderCompletedEventArgsDescriptionMetadata.c(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.k(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
    };
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.c = function (a) {
    };
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.d = function (a) {
        FilterDialogRenderCompletedEventArgsDescriptionMetadata.b(a);
        a.ae("FilterDialogRenderCompletedEventArgs", function () { return new FilterDialogRenderCompletedEventArgsDescription(); });
        a.ad("FilterDialogRenderCompletedEventArgs", FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
    };
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.$t = markType(FilterDialogRenderCompletedEventArgsDescriptionMetadata, 'FilterDialogRenderCompletedEventArgsDescriptionMetadata');
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.a = null;
    return FilterDialogRenderCompletedEventArgsDescriptionMetadata;
}(Base));
export { FilterDialogRenderCompletedEventArgsDescriptionMetadata };
